summaryrefslogtreecommitdiffstats
path: root/kbruch/src/taskview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbruch/src/taskview.cpp')
-rw-r--r--kbruch/src/taskview.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kbruch/src/taskview.cpp b/kbruch/src/taskview.cpp
index a15520a8..6318c7bf 100644
--- a/kbruch/src/taskview.cpp
+++ b/kbruch/src/taskview.cpp
@@ -24,7 +24,7 @@
#include <kapplication.h>
#include <knumvalidator.h>
/* these includes are needed for Qt support */
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqlineedit.h>
@@ -38,9 +38,9 @@
/* ----- public member functions ----- */
/* constructor */
-TaskView::TaskView(TQWidget * parent, const char * name, bool padd_sub,
+TaskView::TaskView(TQWidget * tqparent, const char * name, bool padd_sub,
bool pmul_div, unsigned int pnr_ratios, unsigned int pmax_md):
- ExerciseBase(parent, name), add_sub(padd_sub), mul_div(pmul_div),
+ ExerciseBase(tqparent, name), add_sub(padd_sub), mul_div(pmul_div),
nr_ratios(pnr_ratios), max_md(pmax_md)
{
#ifdef DEBUG
@@ -113,10 +113,10 @@ TaskView::TaskView(TQWidget * parent, const char * name, bool padd_sub,
// --- that is the end of the horizontal line ---
// in RTL desktops, we still need to allign the
- // execise to the left. On Qt4, you can set the direction
- // of the layout to LTR (instead of inherit), but on Qt3
+ // execise to the left. On TQt4, you can set the direction
+ // of the tqlayout to LTR (instead of inherit), but on TQt3
// the only way of fixing it is inserting the widgets in reversed
- // order to the layout.
+ // order to the tqlayout.
//
// if you need help with this feel free to contact me - Diego <elcuco@kde.org> )
// This should fix parts of bug #116831
@@ -152,16 +152,16 @@ TaskView::TaskView(TQWidget * parent, const char * name, bool padd_sub,
m_checkButton->setText(i18n("&Check Task"));
m_checkButton->setDefault(true); // is the default button of the dialog
TQToolTip::add(m_checkButton, i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
- lowerHBox->addWidget(m_checkButton, 1, Qt::AlignRight);
+ lowerHBox->addWidget(m_checkButton, 1, TQt::AlignRight);
TQObject::connect(m_checkButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotCheckButtonClicked()));
// that the user can start typing without moving the focus
numer_edit->setFocus();
- // show the whole layout
+ // show the whole tqlayout
baseWidget->show();
- // show the whole layout
+ // show the whole tqlayout
m_taskWidget->show();
m_resultWidget->hide();
@@ -177,7 +177,7 @@ TaskView::~TaskView()
kdDebug() << "destructor TaskView()" << endl;
#endif
/* no need to delete any child widgets, Qt does it by itself */
}
/** the parameters of task generation can be set with this function */
@@ -24,7 +24,7 @@
#include <kapplication.h>
#include <knumvalidator.h>
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <tqlabel.h>
#include <tqlayout.h>
@@ -177,7 +177,7 @@ TaskView::~TaskView()
kdDebug() << "destructor TaskView()" << endl;
#endif
- /* no need to delete any child widgets, Qt does it by itself */
+ /* no need to delete any child widgets, TQt does it by itself */
}
/** the parameters of task generation can be set with this function */